# pyw-motion
[![PyPI](https://img.shields.io/pypi/v/pyw-motion.svg)](https://pypi.org/project/pyw-motion/)
[![CI](https://github.com/pythonWoods/pyw-motion/actions/workflows/ci.yml/badge.svg)](https://github.com/pythonWoods/pyw-motion/actions/workflows/ci.yml)
[![License](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)

Reserved placeholder for pyw-motion (motion-detection helpers).


## Links utili
Documentazione dev (work-in-progress) → https://pythonwoods.dev/docs/pyw-motion/latest/

Issue tracker → https://github.com/pythonWoods/pyw-motion/issues

Changelog → https://github.com/pythonWoods/pyw-motion/releases

© pythonWoods — MIT License